var namespacecom_1_1sun_1_1star_1_1sheet =
[
    [ "AddressConvention", "namespacecom_1_1sun_1_1star_1_1sheet_1_1AddressConvention.html", [
      [ "LOTUS_A1", "namespacecom_1_1sun_1_1star_1_1sheet_1_1AddressConvention.html#a2a40a74b53ae45d9d11e503b6785eabf", null ],
      [ "OOO", "namespacecom_1_1sun_1_1star_1_1sheet_1_1AddressConvention.html#a05e218e84ee9eb484dc8ff4594ed3485", null ],
      [ "UNSPECIFIED", "namespacecom_1_1sun_1_1star_1_1sheet_1_1AddressConvention.html#a1efc0e2e7a965dd64c3c490ac7e6d8da", null ],
      [ "XL_A1", "namespacecom_1_1sun_1_1star_1_1sheet_1_1AddressConvention.html#a02136c95de37605acf427c9307875026", null ],
      [ "XL_OOX", "namespacecom_1_1sun_1_1star_1_1sheet_1_1AddressConvention.html#ad3c80df59f8361c8b04d469e22385abb", null ],
      [ "XL_R1C1", "namespacecom_1_1sun_1_1star_1_1sheet_1_1AddressConvention.html#a8f6f4d4560a841f3cc5af4ac064b7ccc", null ]
    ] ],
    [ "CellFlags", "namespacecom_1_1sun_1_1star_1_1sheet_1_1CellFlags.html", [
      [ "ANNOTATION", "namespacecom_1_1sun_1_1star_1_1sheet_1_1CellFlags.html#adba7284f7cc89408897cdb5f4897460b", null ],
      [ "DATETIME", "namespacecom_1_1sun_1_1star_1_1sheet_1_1CellFlags.html#ace3f6bcff6a940c19531ad2447bfff01", null ],
      [ "EDITATTR", "namespacecom_1_1sun_1_1star_1_1sheet_1_1CellFlags.html#a54545dc062bc2be2d723d0cc34e8cbd2", null ],
      [ "FORMATTED", "namespacecom_1_1sun_1_1star_1_1sheet_1_1CellFlags.html#a5f8ca689838f513d4741455490a04660", null ],
      [ "FORMULA", "namespacecom_1_1sun_1_1star_1_1sheet_1_1CellFlags.html#a34631f7c91ad6b24140c3027e06613a1", null ],
      [ "HARDATTR", "namespacecom_1_1sun_1_1star_1_1sheet_1_1CellFlags.html#ad43fcb3c5e4f28aa1a1e6e615c5583f7", null ],
      [ "OBJECTS", "namespacecom_1_1sun_1_1star_1_1sheet_1_1CellFlags.html#ac5d29c11cab1c07ae270efec15bece4a", null ],
      [ "STRING", "namespacecom_1_1sun_1_1star_1_1sheet_1_1CellFlags.html#a0f9444c5a241b2cd5f34553b05a18ca8", null ],
      [ "STYLES", "namespacecom_1_1sun_1_1star_1_1sheet_1_1CellFlags.html#a4e82a4ddc5f1d04ea3089d23a10d18e6", null ],
      [ "VALUE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1CellFlags.html#a0e1af5807e933584b7259c7f976f5bcd", null ]
    ] ],
    [ "ColorScaleEntryType", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ColorScaleEntryType.html", [
      [ "COLORSCALE_FORMULA", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ColorScaleEntryType.html#a6e07d75ae8340296335562a7707bc627", null ],
      [ "COLORSCALE_MAX", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ColorScaleEntryType.html#adeb06754b6270e99c64fb42752a2542a", null ],
      [ "COLORSCALE_MIN", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ColorScaleEntryType.html#ac2b74347587d5cced328abbffe8d1acc", null ],
      [ "COLORSCALE_PERCENT", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ColorScaleEntryType.html#a0dde735efe94c9e00f6ec88609bb9f69", null ],
      [ "COLORSCALE_PERCENTILE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ColorScaleEntryType.html#a6c527dc42f81676bd8ebc3177b7f488c", null ],
      [ "COLORSCALE_VALUE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ColorScaleEntryType.html#accdf00e88b5e185005b7037a3bbf9ea2", null ]
    ] ],
    [ "ConditionEntryType", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionEntryType.html", [
      [ "COLORSCALE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionEntryType.html#af5f79eac37b0cb3a7a0f9c645391338b", null ],
      [ "CONDITION", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionEntryType.html#a25389dbd17be0ce7d2ce492ad48c78a7", null ],
      [ "DATABAR", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionEntryType.html#a1fe41b127607a3b747e98a1ba2f02333", null ],
      [ "DATE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionEntryType.html#a11b5949fafb9da6e72908bc220dbe6f5", null ],
      [ "ICONSET", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionEntryType.html#a546d4c9bc1fb47b53dcb5b4e03b51ce0", null ]
    ] ],
    [ "ConditionFormatOperator", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionFormatOperator.html", [
      [ "ABOVE_AVERAGE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionFormatOperator.html#ae8e4e3f65645f204b2318f15cf97b398", null ],
      [ "ABOVE_EQUAL_AVERAGE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionFormatOperator.html#addde6d2bc3e17425916ce850d4454f75", null ],
      [ "BEGINS_WITH", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionFormatOperator.html#a84b419a868497d60e5f193a79af59cc4", null ],
      [ "BELOW_AVERAGE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionFormatOperator.html#acc562f72ae68091ab6a2a6dc37a34332", null ],
      [ "BELOW_EQUAL_AVERAGE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionFormatOperator.html#af9d0c6ab3f8418e74232dfc6dc9a997f", null ],
      [ "BETWEEN", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionFormatOperator.html#ac0d953b8965ae4a5383846d377b3fffd", null ],
      [ "BOTTOM_N_ELEMENTS", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionFormatOperator.html#a977fef4280654568a6a405042e19eb38", null ],
      [ "BOTTOM_N_PERCENT", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionFormatOperator.html#a851e90caba2ab9e49ddf78ed4c591dee", null ],
      [ "CONTAINS", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionFormatOperator.html#a97d38e1b88aebdaf4866a8fb3745db8e", null ],
      [ "DUPLICATE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionFormatOperator.html#a1678c58b9ba4043b3bed712dd7a57b6b", null ],
      [ "ENDS_WITH", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionFormatOperator.html#a0bfd5a6bfef5034fd2e455ad37f64a8d", null ],
      [ "EQUAL", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionFormatOperator.html#a32c4f53a31a9c4a7c9ec3377ba348adf", null ],
      [ "ERROR", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionFormatOperator.html#ae968c8f87ff6473a2da7b9d0bda62bf0", null ],
      [ "EXPRESSION", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionFormatOperator.html#aca1ef75c5a418f2a7eeb1ca492cfb87b", null ],
      [ "GREATER", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionFormatOperator.html#ab17bca9a5432ca89287d567172263f4d", null ],
      [ "GREATER_EQUAL", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionFormatOperator.html#ab9211a16314df137cc3d0991250a7e8e", null ],
      [ "LESS", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionFormatOperator.html#af14a4e49057fc70e86aad2e2291c55c9", null ],
      [ "LESS_EQUAL", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionFormatOperator.html#a65bd404b259c30e850829aaf6df66be0", null ],
      [ "NO_ERROR", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionFormatOperator.html#abe85056b87de0814ed484a20b91158e2", null ],
      [ "NOT_BETWEEN", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionFormatOperator.html#a7aafb4a95c4d9495cc86b95b3c91fe77", null ],
      [ "NOT_CONTAINS", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionFormatOperator.html#a46f016772e5eee9cba6a0524b38e0f89", null ],
      [ "NOT_EQUAL", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionFormatOperator.html#aa8f066e1451335a79b236d0cb7399670", null ],
      [ "TOP_N_ELEMENTS", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionFormatOperator.html#a3f790640d16907054195bef689870dd4", null ],
      [ "TOP_N_PERCENT", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionFormatOperator.html#afa8649cfdb93aadd8a0f498b06d07a8e", null ],
      [ "UNIQUE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionFormatOperator.html#aa334f34fd2c16763a4d7a7970407f69c", null ]
    ] ],
    [ "ConditionOperator2", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionOperator2.html", [
      [ "BETWEEN", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionOperator2.html#ac0d953b8965ae4a5383846d377b3fffd", null ],
      [ "DUPLICATE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionOperator2.html#a1678c58b9ba4043b3bed712dd7a57b6b", null ],
      [ "EQUAL", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionOperator2.html#a32c4f53a31a9c4a7c9ec3377ba348adf", null ],
      [ "FORMULA", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionOperator2.html#a34631f7c91ad6b24140c3027e06613a1", null ],
      [ "GREATER", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionOperator2.html#ab17bca9a5432ca89287d567172263f4d", null ],
      [ "GREATER_EQUAL", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionOperator2.html#ab9211a16314df137cc3d0991250a7e8e", null ],
      [ "LESS", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionOperator2.html#af14a4e49057fc70e86aad2e2291c55c9", null ],
      [ "LESS_EQUAL", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionOperator2.html#a65bd404b259c30e850829aaf6df66be0", null ],
      [ "NONE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionOperator2.html#ad48bab0bc27abeb93105a0c2c3ca707a", null ],
      [ "NOT_BETWEEN", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionOperator2.html#a7aafb4a95c4d9495cc86b95b3c91fe77", null ],
      [ "NOT_DUPLICATE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionOperator2.html#ab6c9cf57d7cfa1f16cce768cc328b70f", null ],
      [ "NOT_EQUAL", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionOperator2.html#aa8f066e1451335a79b236d0cb7399670", null ]
    ] ],
    [ "DataBarAxis", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataBarAxis.html", [
      [ "AXIS_AUTOMATIC", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataBarAxis.html#ab776821341eccb6552542809862484cf", null ],
      [ "AXIS_MIDDLE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataBarAxis.html#a6b04195c9f22711b62a199896f0946d2", null ],
      [ "AXIS_NONE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataBarAxis.html#ad49dd74d9a856ed61291382f39f75869", null ]
    ] ],
    [ "DataBarEntryType", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataBarEntryType.html", [
      [ "DATABAR_AUTO", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataBarEntryType.html#a0d12d83a7a416e15f07f1aa88a3e90ed", null ],
      [ "DATABAR_FORMULA", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataBarEntryType.html#add6485272d24dfb516669ffafee1b9d9", null ],
      [ "DATABAR_MAX", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataBarEntryType.html#aeea968d34773c45964df1626db0406a8", null ],
      [ "DATABAR_MIN", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataBarEntryType.html#af82f647f99c8344bef1e750fcaca5a84", null ],
      [ "DATABAR_PERCENT", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataBarEntryType.html#a94ada1a7349081e9aba591ac3b8c0c16", null ],
      [ "DATABAR_PERCENTILE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataBarEntryType.html#a268c9ee069018404b34bfc4c228b1ea5", null ],
      [ "DATABAR_VALUE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataBarEntryType.html#a5de5742fe90c77b7944727f4223e8551", null ]
    ] ],
    [ "DataPilotFieldGroupBy", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldGroupBy.html", [
      [ "DAYS", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldGroupBy.html#ab95432a4349315a9c95311a1e876936c", null ],
      [ "HOURS", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldGroupBy.html#a30a53b05e46c3595980186b994f9f056", null ],
      [ "MINUTES", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldGroupBy.html#a1eff1b1607c638b212e598b888d45cbb", null ],
      [ "MONTHS", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldGroupBy.html#adc97d8d9e1c71df2991c9951c8a46de2", null ],
      [ "QUARTERS", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldGroupBy.html#a0a3c763ee3f5f0c045e0527cfd4cd853", null ],
      [ "SECONDS", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldGroupBy.html#af6b2daf911358f727d654eeb6c6051c0", null ],
      [ "YEARS", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldGroupBy.html#a29ae433553a139eeb9937e2c8ce0746d", null ]
    ] ],
    [ "DataPilotFieldLayoutMode", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldLayoutMode.html", [
      [ "COMPACT_LAYOUT", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldLayoutMode.html#afb67d7ef98d1d65516732a71aca188fd", null ],
      [ "OUTLINE_SUBTOTALS_BOTTOM", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldLayoutMode.html#a66b5d91b52d3139506f07a7eb534e615", null ],
      [ "OUTLINE_SUBTOTALS_TOP", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldLayoutMode.html#a15c8869aec7b73e92d27009f080b043a", null ],
      [ "TABULAR_LAYOUT", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldLayoutMode.html#a4547370838ecf285ed2480bef42ac395", null ]
    ] ],
    [ "DataPilotFieldReferenceItemType", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldReferenceItemType.html", [
      [ "NAMED", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldReferenceItemType.html#a5f34f4897e28ff97e21440949c7cd1f9", null ],
      [ "NEXT", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldReferenceItemType.html#a560902a8c15dc49866276f87e7239a16", null ],
      [ "PREVIOUS", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldReferenceItemType.html#a6cf024ca6740e30fcaa6c96fc4b3792f", null ]
    ] ],
    [ "DataPilotFieldReferenceType", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldReferenceType.html", [
      [ "COLUMN_PERCENTAGE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldReferenceType.html#a91ee031e8a21037e9beddf9cc7866bbb", null ],
      [ "INDEX", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldReferenceType.html#a80755929a2b3460ef13919863677c727", null ],
      [ "ITEM_DIFFERENCE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldReferenceType.html#a6cbf5359058af527a8600ad897af212b", null ],
      [ "ITEM_PERCENTAGE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldReferenceType.html#abd9536f5ee77fe8bfac66da782e5e967", null ],
      [ "ITEM_PERCENTAGE_DIFFERENCE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldReferenceType.html#ace783aea4f05c9be749a0129b2910cdf", null ],
      [ "NONE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldReferenceType.html#ad48bab0bc27abeb93105a0c2c3ca707a", null ],
      [ "ROW_PERCENTAGE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldReferenceType.html#a9cd1e4b22023f62d60c8c308378d6124", null ],
      [ "RUNNING_TOTAL", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldReferenceType.html#a15760ff4029c2b4cc79f8a871bbb457c", null ],
      [ "TOTAL_PERCENTAGE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldReferenceType.html#a9e9a8425d86e15d77c8160ca1eccb1be", null ]
    ] ],
    [ "DataPilotFieldShowItemsMode", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldShowItemsMode.html", [
      [ "FROM_BOTTOM", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldShowItemsMode.html#a6dbf48e24fe34213fa7fe3576eafe198", null ],
      [ "FROM_TOP", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldShowItemsMode.html#a67b893e6874b090f961fd22a91ded692", null ]
    ] ],
    [ "DataPilotFieldSortMode", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldSortMode.html", [
      [ "DATA", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldSortMode.html#a8a9dbbf06c50c1ed30fb57e920d613fc", null ],
      [ "MANUAL", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldSortMode.html#aef34e06bf1851bb45d3111b5771a4e58", null ],
      [ "NAME", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldSortMode.html#a7e1c77dbd8293f3248b0cb1c64423dac", null ],
      [ "NONE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldSortMode.html#ad48bab0bc27abeb93105a0c2c3ca707a", null ]
    ] ],
    [ "DataPilotOutputRangeType", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotOutputRangeType.html", [
      [ "RESULT", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotOutputRangeType.html#a0ff0855af70f7ad842a551a12bfa370a", null ],
      [ "TABLE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotOutputRangeType.html#afb1a2d5b6654c35a1cedaa57044026aa", null ],
      [ "WHOLE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotOutputRangeType.html#a1a874ccf785803d8faf05507e180e776", null ]
    ] ],
    [ "DataPilotTablePositionType", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotTablePositionType.html", [
      [ "COLUMN_HEADER", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotTablePositionType.html#ae146a7522dc0ac3b7eece7841e28df20", null ],
      [ "NOT_IN_TABLE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotTablePositionType.html#acbc983fac42410b7d88052b51bbad606", null ],
      [ "OTHER", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotTablePositionType.html#a3d8b0e16a3f79539f5d4acd28cdc59c9", null ],
      [ "RESULT", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotTablePositionType.html#a0ff0855af70f7ad842a551a12bfa370a", null ],
      [ "ROW_HEADER", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotTablePositionType.html#ad1f542bbcfe1efd7ed1f6f30c1f7049a", null ]
    ] ],
    [ "DataResultFlags", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataResultFlags.html", [
      [ "ERROR", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataResultFlags.html#ae968c8f87ff6473a2da7b9d0bda62bf0", null ],
      [ "HASDATA", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataResultFlags.html#ad39bd9a9d39b96e1246b0922268e5a01", null ],
      [ "SUBTOTAL", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DataResultFlags.html#a5e71afc52b4c776203a03dc6292270ce", null ]
    ] ],
    [ "DateType", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DateType.html", [
      [ "LAST7DAYS", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DateType.html#a55ea03f717a6c41de9b069895172844c", null ],
      [ "LASTMONTH", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DateType.html#a462a570c6523d94b4bfc3f629f150fbf", null ],
      [ "LASTWEEK", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DateType.html#af6d02f6a68434ab408d8d102a89c313c", null ],
      [ "LASTYEAR", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DateType.html#a7e7b77963c7e412f519ecef7bab961b2", null ],
      [ "NEXTMONTH", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DateType.html#a4f3d4b2b4e3c89f1509012dda0ba6b39", null ],
      [ "NEXTWEEK", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DateType.html#a1800528e67f45224bce241043b54e74d", null ],
      [ "NEXTYEAR", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DateType.html#a2f6c28319358c77922d123e262682b4a", null ],
      [ "THISMONTH", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DateType.html#a6f3d39e7161866d6214551781aec6bc7", null ],
      [ "THISWEEK", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DateType.html#a6b140151d53bc3111c6699522ad478bf", null ],
      [ "THISYEAR", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DateType.html#a34c9cf6d0c730e9e95362182a4af6333", null ],
      [ "TODAY", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DateType.html#a8579d95afb77b7c8829871c81858c056", null ],
      [ "TOMORROW", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DateType.html#a103c8cc67cb11bd9b19def1d8d71c656", null ],
      [ "YESTERDAY", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DateType.html#aa2a60e92e868ddbeb937fe14087fb3a1", null ]
    ] ],
    [ "DimensionFlags", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DimensionFlags.html", [
      [ "NO_COLUMN_ORIENTATION", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DimensionFlags.html#aad9cabe5c06460dc2937e7b7a69cdef9", null ],
      [ "NO_DATA_ORIENTATION", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DimensionFlags.html#a8d18d6bff1e4b69bd35cf28130bf520c", null ],
      [ "NO_PAGE_ORIENTATION", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DimensionFlags.html#a39fc8868121860d646ed27cf087d2c34", null ],
      [ "NO_ROW_ORIENTATION", "namespacecom_1_1sun_1_1star_1_1sheet_1_1DimensionFlags.html#aae37607b09853007b64ddade88b0c7fb", null ]
    ] ],
    [ "ExternalLinkType", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ExternalLinkType.html", [
      [ "DDE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ExternalLinkType.html#a67e57d0b2bfdf4ed387ec87f350c4aba", null ],
      [ "DOCUMENT", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ExternalLinkType.html#af2b7a0d9109037df84ccb7e210e602a4", null ],
      [ "SELF", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ExternalLinkType.html#acdc6cf5d19d2ad00e40b50975f419e4f", null ],
      [ "SPECIAL", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ExternalLinkType.html#a43c6697324e526da005ad3f7a1326935", null ],
      [ "UNKNOWN", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ExternalLinkType.html#a9dbd869263172de0ca594e5e3fdc7ea9", null ]
    ] ],
    [ "FilterFieldType", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FilterFieldType.html", [
      [ "BACKGROUND_COLOR", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FilterFieldType.html#ab04662969af7406469587125c7d66859", null ],
      [ "DATE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FilterFieldType.html#a11b5949fafb9da6e72908bc220dbe6f5", null ],
      [ "NUMERIC", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FilterFieldType.html#aa3928670d75d37b1eea1f72c769b2a97", null ],
      [ "STRING", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FilterFieldType.html#a0f9444c5a241b2cd5f34553b05a18ca8", null ],
      [ "TEXT_COLOR", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FilterFieldType.html#a7aa8f050caaf839621189408f6d0cbeb", null ]
    ] ],
    [ "FilterOperator2", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FilterOperator2.html", [
      [ "BEGINS_WITH", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FilterOperator2.html#a84b419a868497d60e5f193a79af59cc4", null ],
      [ "BOTTOM_PERCENT", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FilterOperator2.html#a260201970df8bfa3748762676beeb37e", null ],
      [ "BOTTOM_VALUES", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FilterOperator2.html#ad9e762e4ba423b0c9b74ccb4aa3ab89b", null ],
      [ "CONTAINS", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FilterOperator2.html#a97d38e1b88aebdaf4866a8fb3745db8e", null ],
      [ "DOES_NOT_BEGIN_WITH", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FilterOperator2.html#abd24a7b91aa359bca38ca1ba1f20d6cd", null ],
      [ "DOES_NOT_CONTAIN", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FilterOperator2.html#a8f3b53bd2bb9c61e8cc43b60eb560dcf", null ],
      [ "DOES_NOT_END_WITH", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FilterOperator2.html#a4bb7fae9a44cd043da2ea20a43d21c91", null ],
      [ "EMPTY", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FilterOperator2.html#a0cfc758e1716bc5b4f69c0fa1cfb3f48", null ],
      [ "ENDS_WITH", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FilterOperator2.html#a0bfd5a6bfef5034fd2e455ad37f64a8d", null ],
      [ "EQUAL", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FilterOperator2.html#a32c4f53a31a9c4a7c9ec3377ba348adf", null ],
      [ "GREATER", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FilterOperator2.html#ab17bca9a5432ca89287d567172263f4d", null ],
      [ "GREATER_EQUAL", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FilterOperator2.html#ab9211a16314df137cc3d0991250a7e8e", null ],
      [ "LESS", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FilterOperator2.html#af14a4e49057fc70e86aad2e2291c55c9", null ],
      [ "LESS_EQUAL", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FilterOperator2.html#a65bd404b259c30e850829aaf6df66be0", null ],
      [ "NOT_EMPTY", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FilterOperator2.html#a5d4c9db2a195addfec46af72b757801c", null ],
      [ "NOT_EQUAL", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FilterOperator2.html#aa8f066e1451335a79b236d0cb7399670", null ],
      [ "TOP_PERCENT", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FilterOperator2.html#a97808006dc0342f51e95eab94bbc3f07", null ],
      [ "TOP_VALUES", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FilterOperator2.html#a76c85837274e5b2456914ee5aa46fdf5", null ]
    ] ],
    [ "FormulaLanguage", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FormulaLanguage.html", [
      [ "API", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FormulaLanguage.html#a16677fd818715f0f29e23c457b7ba4a3", null ],
      [ "ENGLISH", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FormulaLanguage.html#a7df0380d22953010a5431a5ea852009b", null ],
      [ "NATIVE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FormulaLanguage.html#aedf387ef076dc2fd8f263a5ffe6f71ac", null ],
      [ "ODF_11", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FormulaLanguage.html#afcd3bef216f49faae73ee2ecc7cd0e50", null ],
      [ "ODFF", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FormulaLanguage.html#a56e0dbd6a0fbed473f7d3956297d4065", null ],
      [ "OOXML", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FormulaLanguage.html#a70a089fd55b1cbccf0b9488bd7002961", null ],
      [ "XL_ENGLISH", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FormulaLanguage.html#a508d1f284e3e102e37f709863fa44c7e", null ]
    ] ],
    [ "FormulaMapGroup", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FormulaMapGroup.html", [
      [ "ALL_EXCEPT_SPECIAL", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FormulaMapGroup.html#af276eee10c3949e59c4d570e9afd36cb", null ],
      [ "ARRAY_SEPARATORS", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FormulaMapGroup.html#a8ac85f44990290be3c6a83c0f58ec92f", null ],
      [ "BINARY_OPERATORS", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FormulaMapGroup.html#af026bee10244fb4b08af6265feb80578", null ],
      [ "FUNCTIONS", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FormulaMapGroup.html#aeea6935a04e0d27ee586c085909b4f77", null ],
      [ "SEPARATORS", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FormulaMapGroup.html#aa90d34aa8a663cacba66dd010a168fb7", null ],
      [ "SPECIAL", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FormulaMapGroup.html#a43c6697324e526da005ad3f7a1326935", null ],
      [ "UNARY_OPERATORS", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FormulaMapGroup.html#a06ec96035f45adeb618795a112b7f6eb", null ]
    ] ],
    [ "FormulaMapGroupSpecialOffset", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FormulaMapGroupSpecialOffset.html", [
      [ "BAD", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FormulaMapGroupSpecialOffset.html#adb26e5a376d6d7028251be958c873a62", null ],
      [ "CALL", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FormulaMapGroupSpecialOffset.html#a4b94e7b79e797bac72c475a3bd70aa7d", null ],
      [ "COL_ROW_NAME", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FormulaMapGroupSpecialOffset.html#aea5d011a1dc73e7ed5a217b0ac1edc6f", null ],
      [ "DB_AREA", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FormulaMapGroupSpecialOffset.html#a7a74a2a508faac8ae79b8a335c5bb933", null ],
      [ "EXTERNAL", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FormulaMapGroupSpecialOffset.html#a92f34098c1b33c4daa402747399140df", null ],
      [ "MACRO", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FormulaMapGroupSpecialOffset.html#adf0151dda7658ec9675c125f6b3cad6e", null ],
      [ "MAT_REF", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FormulaMapGroupSpecialOffset.html#a10da80c80ef8be5a441473da7d2eee2c", null ],
      [ "MISSING", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FormulaMapGroupSpecialOffset.html#a375ac23dc3b90cb52a95bf6c20aa4e82", null ],
      [ "NAME", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FormulaMapGroupSpecialOffset.html#a7e1c77dbd8293f3248b0cb1c64423dac", null ],
      [ "NO_NAME", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FormulaMapGroupSpecialOffset.html#a5032961b624f09dc40df4a19b6110c9f", null ],
      [ "PUSH", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FormulaMapGroupSpecialOffset.html#a471a10c563d0925c8014af0602b6101e", null ],
      [ "SPACES", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FormulaMapGroupSpecialOffset.html#a1a9bf1abd61cb7be475f4ce5acbef50f", null ],
      [ "STOP", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FormulaMapGroupSpecialOffset.html#a41826b9c81401abc2e0b4a9fd84f9eba", null ],
      [ "WHITESPACE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FormulaMapGroupSpecialOffset.html#a28d69b8dc6d3c64952f7159c4db89717", null ]
    ] ],
    [ "FormulaResult", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FormulaResult.html", [
      [ "ERROR", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FormulaResult.html#ae968c8f87ff6473a2da7b9d0bda62bf0", null ],
      [ "STRING", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FormulaResult.html#a0f9444c5a241b2cd5f34553b05a18ca8", null ],
      [ "VALUE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FormulaResult.html#a0e1af5807e933584b7259c7f976f5bcd", null ]
    ] ],
    [ "FunctionCategory", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FunctionCategory.html", [
      [ "ADDIN", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FunctionCategory.html#ad3deed66ebbd917246f4a4be088525c1", null ],
      [ "DATABASE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FunctionCategory.html#a33e50522078e8918541cc857469fb8ce", null ],
      [ "DATETIME", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FunctionCategory.html#ace3f6bcff6a940c19531ad2447bfff01", null ],
      [ "FINANCIAL", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FunctionCategory.html#aac45f01194c73467de907cafb45e3213", null ],
      [ "INFORMATION", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FunctionCategory.html#a9ec838fd18cccfe8b5e1e7c4c2dff50f", null ],
      [ "LOGICAL", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FunctionCategory.html#a6839d3fbf5f1604ccde6c72c8a7ce43d", null ],
      [ "MATHEMATICAL", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FunctionCategory.html#a016b203b189ebb3a4f59714630bd9ff7", null ],
      [ "MATRIX", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FunctionCategory.html#a8122e2572842a72205995c18c385be85", null ],
      [ "SPREADSHEET", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FunctionCategory.html#aecc3e24ba0de76a170dfc3e51e4e58fa", null ],
      [ "STATISTICAL", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FunctionCategory.html#ab4ccbc9c85f79fb7f560f40496ed90d0", null ],
      [ "TEXT", "namespacecom_1_1sun_1_1star_1_1sheet_1_1FunctionCategory.html#adc4e5ec11e961d2f2831a86cb6fe546b", null ]
    ] ],
    [ "GeneralFunction2", "namespacecom_1_1sun_1_1star_1_1sheet_1_1GeneralFunction2.html", [
      [ "AUTO", "namespacecom_1_1sun_1_1star_1_1sheet_1_1GeneralFunction2.html#ae1d9917b74ad9620595a94dbceef8a5b", null ],
      [ "AVERAGE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1GeneralFunction2.html#a99f3f2451149cc68e71ef6a15ba8b66e", null ],
      [ "COUNT", "namespacecom_1_1sun_1_1star_1_1sheet_1_1GeneralFunction2.html#af38414eb387ab2823e7c65b84985ba7f", null ],
      [ "COUNTNUMS", "namespacecom_1_1sun_1_1star_1_1sheet_1_1GeneralFunction2.html#aae44ab3cdb8a4c30d8c614f188c6ac49", null ],
      [ "MAX", "namespacecom_1_1sun_1_1star_1_1sheet_1_1GeneralFunction2.html#a5d38ee21ceebaa580f53f742fdf5dd9d", null ],
      [ "MEDIAN", "namespacecom_1_1sun_1_1star_1_1sheet_1_1GeneralFunction2.html#a07aa6ee78aae135972d79d3b4f25b128", null ],
      [ "MIN", "namespacecom_1_1sun_1_1star_1_1sheet_1_1GeneralFunction2.html#a611d5100dbd668af8673302a2fae0899", null ],
      [ "NONE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1GeneralFunction2.html#a87d5fdeecd058bf6c4bf4fddb6724cd8", null ],
      [ "PRODUCT", "namespacecom_1_1sun_1_1star_1_1sheet_1_1GeneralFunction2.html#a99f1806eb8b8c6c21bb2e6066b671ca3", null ],
      [ "STDEV", "namespacecom_1_1sun_1_1star_1_1sheet_1_1GeneralFunction2.html#ac282b94e17121f3c419cf9fe1e4a8024", null ],
      [ "STDEVP", "namespacecom_1_1sun_1_1star_1_1sheet_1_1GeneralFunction2.html#ada9e053a854c9082de0ce94100f82449", null ],
      [ "SUM", "namespacecom_1_1sun_1_1star_1_1sheet_1_1GeneralFunction2.html#a2c88d8c95dccabda15f71df61239c726", null ],
      [ "VAR", "namespacecom_1_1sun_1_1star_1_1sheet_1_1GeneralFunction2.html#a44e92be74282881b9efe332a45feb2bd", null ],
      [ "VARP", "namespacecom_1_1sun_1_1star_1_1sheet_1_1GeneralFunction2.html#a4b50157d9d72905db6a84ed48d4bb910", null ]
    ] ],
    [ "IconSetFormatEntry", "namespacecom_1_1sun_1_1star_1_1sheet_1_1IconSetFormatEntry.html", [
      [ "ICONSET_FORMULA", "namespacecom_1_1sun_1_1star_1_1sheet_1_1IconSetFormatEntry.html#aa468dd187a7e381ae79a231f2d002ec4", null ],
      [ "ICONSET_MIN", "namespacecom_1_1sun_1_1star_1_1sheet_1_1IconSetFormatEntry.html#ad5596ac4d3c043451ac78aa858bcc7e6", null ],
      [ "ICONSET_PERCENT", "namespacecom_1_1sun_1_1star_1_1sheet_1_1IconSetFormatEntry.html#a17fdd5d24b6e1eb90cf440eebfa1f6e1", null ],
      [ "ICONSET_PERCENTILE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1IconSetFormatEntry.html#aad2ea220eb6523df20193b662a91c810", null ],
      [ "ICONSET_VALUE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1IconSetFormatEntry.html#a9910e6f920f69f7f76eb8747afec70c3", null ]
    ] ],
    [ "IconSetType", "namespacecom_1_1sun_1_1star_1_1sheet_1_1IconSetType.html", [
      [ "ICONSET_3ARROWS", "namespacecom_1_1sun_1_1star_1_1sheet_1_1IconSetType.html#a8c6ee9fb2147e8eae8b9a2a7c517c876", null ],
      [ "ICONSET_3ARROWS_GRAY", "namespacecom_1_1sun_1_1star_1_1sheet_1_1IconSetType.html#a679b79a0737c274f6ec05d683c72cae0", null ],
      [ "ICONSET_3COLOR_SIMILIES", "namespacecom_1_1sun_1_1star_1_1sheet_1_1IconSetType.html#a989b3be95de6982c63276df0768ea162", null ],
      [ "ICONSET_3FLAGS", "namespacecom_1_1sun_1_1star_1_1sheet_1_1IconSetType.html#aa0ddcbbab84d2aa99e4681306e9fd672", null ],
      [ "ICONSET_3SIGNS", "namespacecom_1_1sun_1_1star_1_1sheet_1_1IconSetType.html#aabedf3578628eeb52baf5dd081ae2fe6", null ],
      [ "ICONSET_3SMILIES", "namespacecom_1_1sun_1_1star_1_1sheet_1_1IconSetType.html#ae7569892fcda2d95209a97c106e81d7d", null ],
      [ "ICONSET_3SYMBOLS", "namespacecom_1_1sun_1_1star_1_1sheet_1_1IconSetType.html#af8d45f2825c651f84af08e48d8fcc93c", null ],
      [ "ICONSET_3SYMBOLS2", "namespacecom_1_1sun_1_1star_1_1sheet_1_1IconSetType.html#a8e2d328fdad52ef774dd5664fd050cbf", null ],
      [ "ICONSET_3TRAFFICLIGHTS1", "namespacecom_1_1sun_1_1star_1_1sheet_1_1IconSetType.html#ad7149fc1e8d8807db88db3ae6895db7a", null ],
      [ "ICONSET_3TRAFFICLIGHTS2", "namespacecom_1_1sun_1_1star_1_1sheet_1_1IconSetType.html#a5fc56ddfda49d8bbcab90a5df0aa51f5", null ],
      [ "ICONSET_4ARROWS", "namespacecom_1_1sun_1_1star_1_1sheet_1_1IconSetType.html#a13e213664fc45f05b303c8128abb05de", null ],
      [ "ICONSET_4ARROWS_GRAY", "namespacecom_1_1sun_1_1star_1_1sheet_1_1IconSetType.html#acd88ea0db4c2e387daff99315fe376c6", null ],
      [ "ICONSET_4RATING", "namespacecom_1_1sun_1_1star_1_1sheet_1_1IconSetType.html#a241c8bd8c8d7788a7b6399fc0d787612", null ],
      [ "ICONSET_4RED_TO_BLACK", "namespacecom_1_1sun_1_1star_1_1sheet_1_1IconSetType.html#a31b958b2dfc98ee7e3419a3064dada5b", null ],
      [ "ICONSET_4TRAFFICLIGHTS", "namespacecom_1_1sun_1_1star_1_1sheet_1_1IconSetType.html#ade953393ce98d7b04ad862d74aac7a36", null ],
      [ "ICONSET_5ARROWS", "namespacecom_1_1sun_1_1star_1_1sheet_1_1IconSetType.html#a523983fdecafcb6aec0bdcfa765323c4", null ],
      [ "ICONSET_5ARROWS_GRAY", "namespacecom_1_1sun_1_1star_1_1sheet_1_1IconSetType.html#a73c3f173a943cce204bedbdba4032596", null ],
      [ "ICONSET_5QUARTERS", "namespacecom_1_1sun_1_1star_1_1sheet_1_1IconSetType.html#a531bc3ee2336430ae28f91b11880a849", null ],
      [ "ICONSET_5RATINGS", "namespacecom_1_1sun_1_1star_1_1sheet_1_1IconSetType.html#aec1da19a791f0159e4d4fe1834b33afb", null ]
    ] ],
    [ "MemberResultFlags", "namespacecom_1_1sun_1_1star_1_1sheet_1_1MemberResultFlags.html", [
      [ "CONTINUE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1MemberResultFlags.html#a1f9125b5d4de8abdc4506171bedb25e1", null ],
      [ "GRANDTOTAL", "namespacecom_1_1sun_1_1star_1_1sheet_1_1MemberResultFlags.html#aacf9d35593112f45d6afaf1768efc44a", null ],
      [ "HASMEMBER", "namespacecom_1_1sun_1_1star_1_1sheet_1_1MemberResultFlags.html#a8f82af54686fe72aeba9ed103fb5b49c", null ],
      [ "NUMERIC", "namespacecom_1_1sun_1_1star_1_1sheet_1_1MemberResultFlags.html#aa3928670d75d37b1eea1f72c769b2a97", null ],
      [ "SUBTOTAL", "namespacecom_1_1sun_1_1star_1_1sheet_1_1MemberResultFlags.html#a5e71afc52b4c776203a03dc6292270ce", null ]
    ] ],
    [ "MoveDirection", "namespacecom_1_1sun_1_1star_1_1sheet_1_1MoveDirection.html", [
      [ "DOWN", "namespacecom_1_1sun_1_1star_1_1sheet_1_1MoveDirection.html#a77bf936d4e199de2e9728861f0d4825c", null ],
      [ "LEFT", "namespacecom_1_1sun_1_1star_1_1sheet_1_1MoveDirection.html#a105d61332f9450fb1986a38e7243c3aa", null ],
      [ "RIGHT", "namespacecom_1_1sun_1_1star_1_1sheet_1_1MoveDirection.html#a0149ac9c0344cfbfd5771ce1a96af612", null ],
      [ "UP", "namespacecom_1_1sun_1_1star_1_1sheet_1_1MoveDirection.html#a3b9bffcb7c543fc042aeab85c4403773", null ]
    ] ],
    [ "NamedRangeFlag", "namespacecom_1_1sun_1_1star_1_1sheet_1_1NamedRangeFlag.html", [
      [ "COLUMN_HEADER", "namespacecom_1_1sun_1_1star_1_1sheet_1_1NamedRangeFlag.html#ae146a7522dc0ac3b7eece7841e28df20", null ],
      [ "FILTER_CRITERIA", "namespacecom_1_1sun_1_1star_1_1sheet_1_1NamedRangeFlag.html#aec806e951b27c27616b91808d3fb1ae7", null ],
      [ "HIDDEN", "namespacecom_1_1sun_1_1star_1_1sheet_1_1NamedRangeFlag.html#afab2ad818906b54b5449202580e2f639", null ],
      [ "PRINT_AREA", "namespacecom_1_1sun_1_1star_1_1sheet_1_1NamedRangeFlag.html#a5477bc8bb5e1409bd8ba416fd97e80dd", null ],
      [ "ROW_HEADER", "namespacecom_1_1sun_1_1star_1_1sheet_1_1NamedRangeFlag.html#ad1f542bbcfe1efd7ed1f6f30c1f7049a", null ]
    ] ],
    [ "opencl", "namespacecom_1_1sun_1_1star_1_1sheet_1_1opencl.html", "namespacecom_1_1sun_1_1star_1_1sheet_1_1opencl" ],
    [ "ReferenceFlags", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ReferenceFlags.html", [
      [ "COLUMN_DELETED", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ReferenceFlags.html#ad6baa027da128ef81d550f88334e913d", null ],
      [ "COLUMN_RELATIVE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ReferenceFlags.html#a26572cf4e1d51e42bcd0102df2643657", null ],
      [ "RELATIVE_NAME", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ReferenceFlags.html#a7fa15646cd2b77f1e8c0c9607307e1d5", null ],
      [ "ROW_DELETED", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ReferenceFlags.html#a46fddb8c5b52981b1accd1fd2ff51d26", null ],
      [ "ROW_RELATIVE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ReferenceFlags.html#a2520f2ed93d10b0c05be0ca6cb8bd97c", null ],
      [ "SHEET_3D", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ReferenceFlags.html#a96aec141d9439add5af73f796fb192a1", null ],
      [ "SHEET_DELETED", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ReferenceFlags.html#af445a30748f2892713a49cc52a5f4008", null ],
      [ "SHEET_RELATIVE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1ReferenceFlags.html#af7b0feeb4bba0dd4d4131ea32a31ec48", null ]
    ] ],
    [ "SpreadsheetViewObjectsMode", "namespacecom_1_1sun_1_1star_1_1sheet_1_1SpreadsheetViewObjectsMode.html", [
      [ "HIDE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1SpreadsheetViewObjectsMode.html#a5673349422c7dd5bb484f14d42e3c711", null ],
      [ "SHOW", "namespacecom_1_1sun_1_1star_1_1sheet_1_1SpreadsheetViewObjectsMode.html#ab6c829e2dba9f251c51dde497ae9eaaf", null ]
    ] ],
    [ "StatusBarFunction", "namespacecom_1_1sun_1_1star_1_1sheet_1_1StatusBarFunction.html", [
      [ "AVERAGE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1StatusBarFunction.html#a99f3f2451149cc68e71ef6a15ba8b66e", null ],
      [ "COUNT", "namespacecom_1_1sun_1_1star_1_1sheet_1_1StatusBarFunction.html#af38414eb387ab2823e7c65b84985ba7f", null ],
      [ "COUNTNUMS", "namespacecom_1_1sun_1_1star_1_1sheet_1_1StatusBarFunction.html#aae44ab3cdb8a4c30d8c614f188c6ac49", null ],
      [ "MAX", "namespacecom_1_1sun_1_1star_1_1sheet_1_1StatusBarFunction.html#a5d38ee21ceebaa580f53f742fdf5dd9d", null ],
      [ "MIN", "namespacecom_1_1sun_1_1star_1_1sheet_1_1StatusBarFunction.html#a611d5100dbd668af8673302a2fae0899", null ],
      [ "NONE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1StatusBarFunction.html#a87d5fdeecd058bf6c4bf4fddb6724cd8", null ],
      [ "SUM", "namespacecom_1_1sun_1_1star_1_1sheet_1_1StatusBarFunction.html#a2c88d8c95dccabda15f71df61239c726", null ]
    ] ],
    [ "TableValidationVisibility", "namespacecom_1_1sun_1_1star_1_1sheet_1_1TableValidationVisibility.html", [
      [ "INVISIBLE", "namespacecom_1_1sun_1_1star_1_1sheet_1_1TableValidationVisibility.html#a9042d995a00e3cd18e04eba93317522a", null ],
      [ "SORTEDASCENDING", "namespacecom_1_1sun_1_1star_1_1sheet_1_1TableValidationVisibility.html#a67c8cb3bacc6207d59ca75dc14aae432", null ],
      [ "UNSORTED", "namespacecom_1_1sun_1_1star_1_1sheet_1_1TableValidationVisibility.html#a8c04752201adeb446b357a4ca7df84ba", null ]
    ] ],
    [ "AccessibleCell", "servicecom_1_1sun_1_1star_1_1sheet_1_1AccessibleCell.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1AccessibleCell" ],
    [ "AccessibleCsvCell", "servicecom_1_1sun_1_1star_1_1sheet_1_1AccessibleCsvCell.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1AccessibleCsvCell" ],
    [ "AccessibleCsvRuler", "servicecom_1_1sun_1_1star_1_1sheet_1_1AccessibleCsvRuler.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1AccessibleCsvRuler" ],
    [ "AccessibleCsvTable", "servicecom_1_1sun_1_1star_1_1sheet_1_1AccessibleCsvTable.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1AccessibleCsvTable" ],
    [ "AccessiblePageHeaderFooterAreasView", "servicecom_1_1sun_1_1star_1_1sheet_1_1AccessiblePageHeaderFooterAreasView.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1AccessiblePageHeaderFooterAreasView" ],
    [ "AccessibleSpreadsheet", "servicecom_1_1sun_1_1star_1_1sheet_1_1AccessibleSpreadsheet.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1AccessibleSpreadsheet" ],
    [ "AccessibleSpreadsheetDocumentView", "servicecom_1_1sun_1_1star_1_1sheet_1_1AccessibleSpreadsheetDocumentView.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1AccessibleSpreadsheetDocumentView" ],
    [ "AccessibleSpreadsheetPageView", "servicecom_1_1sun_1_1star_1_1sheet_1_1AccessibleSpreadsheetPageView.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1AccessibleSpreadsheetPageView" ],
    [ "ActivationEvent", "structcom_1_1sun_1_1star_1_1sheet_1_1ActivationEvent.html", "structcom_1_1sun_1_1star_1_1sheet_1_1ActivationEvent" ],
    [ "AddIn", "servicecom_1_1sun_1_1star_1_1sheet_1_1AddIn.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1AddIn" ],
    [ "CellAnnotation", "servicecom_1_1sun_1_1star_1_1sheet_1_1CellAnnotation.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1CellAnnotation" ],
    [ "CellAnnotations", "servicecom_1_1sun_1_1star_1_1sheet_1_1CellAnnotations.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1CellAnnotations" ],
    [ "CellAnnotationsEnumeration", "servicecom_1_1sun_1_1star_1_1sheet_1_1CellAnnotationsEnumeration.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1CellAnnotationsEnumeration" ],
    [ "CellAnnotationShape", "servicecom_1_1sun_1_1star_1_1sheet_1_1CellAnnotationShape.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1CellAnnotationShape" ],
    [ "CellAreaLink", "servicecom_1_1sun_1_1star_1_1sheet_1_1CellAreaLink.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1CellAreaLink" ],
    [ "CellAreaLinks", "servicecom_1_1sun_1_1star_1_1sheet_1_1CellAreaLinks.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1CellAreaLinks" ],
    [ "CellAreaLinksEnumeration", "servicecom_1_1sun_1_1star_1_1sheet_1_1CellAreaLinksEnumeration.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1CellAreaLinksEnumeration" ],
    [ "CellFormatRanges", "servicecom_1_1sun_1_1star_1_1sheet_1_1CellFormatRanges.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1CellFormatRanges" ],
    [ "CellFormatRangesEnumeration", "servicecom_1_1sun_1_1star_1_1sheet_1_1CellFormatRangesEnumeration.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1CellFormatRangesEnumeration" ],
    [ "Cells", "servicecom_1_1sun_1_1star_1_1sheet_1_1Cells.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1Cells" ],
    [ "CellsEnumeration", "servicecom_1_1sun_1_1star_1_1sheet_1_1CellsEnumeration.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1CellsEnumeration" ],
    [ "ColorScale", "servicecom_1_1sun_1_1star_1_1sheet_1_1ColorScale.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1ColorScale" ],
    [ "ComplexReference", "structcom_1_1sun_1_1star_1_1sheet_1_1ComplexReference.html", "structcom_1_1sun_1_1star_1_1sheet_1_1ComplexReference" ],
    [ "ConditionalFormat", "servicecom_1_1sun_1_1star_1_1sheet_1_1ConditionalFormat.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1ConditionalFormat" ],
    [ "ConditionFormatEntry", "servicecom_1_1sun_1_1star_1_1sheet_1_1ConditionFormatEntry.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1ConditionFormatEntry" ],
    [ "ConsolidationDescriptor", "servicecom_1_1sun_1_1star_1_1sheet_1_1ConsolidationDescriptor.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1ConsolidationDescriptor" ],
    [ "CreateDialogFactoryService", "servicecom_1_1sun_1_1star_1_1sheet_1_1CreateDialogFactoryService.html", null ],
    [ "DataBar", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataBar.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataBar" ],
    [ "DatabaseImportDescriptor", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseImportDescriptor.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseImportDescriptor" ],
    [ "DatabaseRange", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange" ],
    [ "DatabaseRanges", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRanges.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRanges" ],
    [ "DatabaseRangesEnumeration", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRangesEnumeration.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRangesEnumeration" ],
    [ "DataPilotDescriptor", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotDescriptor.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotDescriptor" ],
    [ "DataPilotField", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotField.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotField" ],
    [ "DataPilotFieldAutoShowInfo", "structcom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldAutoShowInfo.html", "structcom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldAutoShowInfo" ],
    [ "DataPilotFieldFilter", "structcom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldFilter.html", "structcom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldFilter" ],
    [ "DataPilotFieldGroup", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldGroup.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldGroup" ],
    [ "DataPilotFieldGroupEnumeration", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldGroupEnumeration.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldGroupEnumeration" ],
    [ "DataPilotFieldGroupInfo", "structcom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldGroupInfo.html", "structcom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldGroupInfo" ],
    [ "DataPilotFieldGroupItem", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldGroupItem.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldGroupItem" ],
    [ "DataPilotFieldGroups", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldGroups.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldGroups" ],
    [ "DataPilotFieldGroupsEnumeration", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldGroupsEnumeration.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldGroupsEnumeration" ],
    [ "DataPilotFieldLayoutInfo", "structcom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldLayoutInfo.html", "structcom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldLayoutInfo" ],
    [ "DataPilotFieldReference", "structcom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldReference.html", "structcom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldReference" ],
    [ "DataPilotFields", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFields.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFields" ],
    [ "DataPilotFieldsEnumeration", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldsEnumeration.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldsEnumeration" ],
    [ "DataPilotFieldSortInfo", "structcom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldSortInfo.html", "structcom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldSortInfo" ],
    [ "DataPilotItem", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotItem.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotItem" ],
    [ "DataPilotItems", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotItems.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotItems" ],
    [ "DataPilotItemsEnumeration", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotItemsEnumeration.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotItemsEnumeration" ],
    [ "DataPilotSource", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotSource.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotSource" ],
    [ "DataPilotSourceDimension", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotSourceDimension.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotSourceDimension" ],
    [ "DataPilotSourceDimensions", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotSourceDimensions.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotSourceDimensions" ],
    [ "DataPilotSourceHierarchies", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotSourceHierarchies.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotSourceHierarchies" ],
    [ "DataPilotSourceHierarchy", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotSourceHierarchy.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotSourceHierarchy" ],
    [ "DataPilotSourceLevel", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotSourceLevel.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotSourceLevel" ],
    [ "DataPilotSourceLevels", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotSourceLevels.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotSourceLevels" ],
    [ "DataPilotSourceMember", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotSourceMember.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotSourceMember" ],
    [ "DataPilotSourceMembers", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotSourceMembers.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotSourceMembers" ],
    [ "DataPilotTable", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotTable.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotTable" ],
    [ "DataPilotTableHeaderData", "structcom_1_1sun_1_1star_1_1sheet_1_1DataPilotTableHeaderData.html", "structcom_1_1sun_1_1star_1_1sheet_1_1DataPilotTableHeaderData" ],
    [ "DataPilotTablePositionData", "structcom_1_1sun_1_1star_1_1sheet_1_1DataPilotTablePositionData.html", "structcom_1_1sun_1_1star_1_1sheet_1_1DataPilotTablePositionData" ],
    [ "DataPilotTableResultData", "structcom_1_1sun_1_1star_1_1sheet_1_1DataPilotTableResultData.html", "structcom_1_1sun_1_1star_1_1sheet_1_1DataPilotTableResultData" ],
    [ "DataPilotTables", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotTables.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotTables" ],
    [ "DataPilotTablesEnumeration", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotTablesEnumeration.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotTablesEnumeration" ],
    [ "DataResult", "structcom_1_1sun_1_1star_1_1sheet_1_1DataResult.html", "structcom_1_1sun_1_1star_1_1sheet_1_1DataResult" ],
    [ "DateCondition", "servicecom_1_1sun_1_1star_1_1sheet_1_1DateCondition.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1DateCondition" ],
    [ "DDEItemInfo", "structcom_1_1sun_1_1star_1_1sheet_1_1DDEItemInfo.html", "structcom_1_1sun_1_1star_1_1sheet_1_1DDEItemInfo" ],
    [ "DDELink", "servicecom_1_1sun_1_1star_1_1sheet_1_1DDELink.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1DDELink" ],
    [ "DDELinkInfo", "structcom_1_1sun_1_1star_1_1sheet_1_1DDELinkInfo.html", "structcom_1_1sun_1_1star_1_1sheet_1_1DDELinkInfo" ],
    [ "DDELinks", "servicecom_1_1sun_1_1star_1_1sheet_1_1DDELinks.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1DDELinks" ],
    [ "DDELinksEnumeration", "servicecom_1_1sun_1_1star_1_1sheet_1_1DDELinksEnumeration.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1DDELinksEnumeration" ],
    [ "DocumentSettings", "servicecom_1_1sun_1_1star_1_1sheet_1_1DocumentSettings.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1DocumentSettings" ],
    [ "ExternalDocLink", "servicecom_1_1sun_1_1star_1_1sheet_1_1ExternalDocLink.html", null ],
    [ "ExternalDocLinks", "servicecom_1_1sun_1_1star_1_1sheet_1_1ExternalDocLinks.html", null ],
    [ "ExternalLinkInfo", "structcom_1_1sun_1_1star_1_1sheet_1_1ExternalLinkInfo.html", "structcom_1_1sun_1_1star_1_1sheet_1_1ExternalLinkInfo" ],
    [ "ExternalReference", "structcom_1_1sun_1_1star_1_1sheet_1_1ExternalReference.html", "structcom_1_1sun_1_1star_1_1sheet_1_1ExternalReference" ],
    [ "ExternalSheetCache", "servicecom_1_1sun_1_1star_1_1sheet_1_1ExternalSheetCache.html", null ],
    [ "FilterFieldValue", "structcom_1_1sun_1_1star_1_1sheet_1_1FilterFieldValue.html", "structcom_1_1sun_1_1star_1_1sheet_1_1FilterFieldValue" ],
    [ "FilterFormulaParser", "servicecom_1_1sun_1_1star_1_1sheet_1_1FilterFormulaParser.html", null ],
    [ "FormulaOpCodeMapEntry", "structcom_1_1sun_1_1star_1_1sheet_1_1FormulaOpCodeMapEntry.html", "structcom_1_1sun_1_1star_1_1sheet_1_1FormulaOpCodeMapEntry" ],
    [ "FormulaOpCodeMapper", "servicecom_1_1sun_1_1star_1_1sheet_1_1FormulaOpCodeMapper.html", null ],
    [ "FormulaParser", "servicecom_1_1sun_1_1star_1_1sheet_1_1FormulaParser.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1FormulaParser" ],
    [ "FormulaToken", "structcom_1_1sun_1_1star_1_1sheet_1_1FormulaToken.html", "structcom_1_1sun_1_1star_1_1sheet_1_1FormulaToken" ],
    [ "FunctionAccess", "servicecom_1_1sun_1_1star_1_1sheet_1_1FunctionAccess.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1FunctionAccess" ],
    [ "FunctionArgument", "structcom_1_1sun_1_1star_1_1sheet_1_1FunctionArgument.html", "structcom_1_1sun_1_1star_1_1sheet_1_1FunctionArgument" ],
    [ "FunctionDescription", "servicecom_1_1sun_1_1star_1_1sheet_1_1FunctionDescription.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1FunctionDescription" ],
    [ "FunctionDescriptionEnumeration", "servicecom_1_1sun_1_1star_1_1sheet_1_1FunctionDescriptionEnumeration.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1FunctionDescriptionEnumeration" ],
    [ "FunctionDescriptions", "servicecom_1_1sun_1_1star_1_1sheet_1_1FunctionDescriptions.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1FunctionDescriptions" ],
    [ "GlobalSheetSettings", "servicecom_1_1sun_1_1star_1_1sheet_1_1GlobalSheetSettings.html", null ],
    [ "GoalResult", "structcom_1_1sun_1_1star_1_1sheet_1_1GoalResult.html", "structcom_1_1sun_1_1star_1_1sheet_1_1GoalResult" ],
    [ "HeaderFooterContent", "servicecom_1_1sun_1_1star_1_1sheet_1_1HeaderFooterContent.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1HeaderFooterContent" ],
    [ "IconSet", "servicecom_1_1sun_1_1star_1_1sheet_1_1IconSet.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1IconSet" ],
    [ "LabelRange", "servicecom_1_1sun_1_1star_1_1sheet_1_1LabelRange.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1LabelRange" ],
    [ "LabelRanges", "servicecom_1_1sun_1_1star_1_1sheet_1_1LabelRanges.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1LabelRanges" ],
    [ "LabelRangesEnumeration", "servicecom_1_1sun_1_1star_1_1sheet_1_1LabelRangesEnumeration.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1LabelRangesEnumeration" ],
    [ "LocalizedName", "structcom_1_1sun_1_1star_1_1sheet_1_1LocalizedName.html", "structcom_1_1sun_1_1star_1_1sheet_1_1LocalizedName" ],
    [ "MemberResult", "structcom_1_1sun_1_1star_1_1sheet_1_1MemberResult.html", "structcom_1_1sun_1_1star_1_1sheet_1_1MemberResult" ],
    [ "NamedRange", "servicecom_1_1sun_1_1star_1_1sheet_1_1NamedRange.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1NamedRange" ],
    [ "NamedRanges", "servicecom_1_1sun_1_1star_1_1sheet_1_1NamedRanges.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1NamedRanges" ],
    [ "NamedRangesEnumeration", "servicecom_1_1sun_1_1star_1_1sheet_1_1NamedRangesEnumeration.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1NamedRangesEnumeration" ],
    [ "NameToken", "structcom_1_1sun_1_1star_1_1sheet_1_1NameToken.html", "structcom_1_1sun_1_1star_1_1sheet_1_1NameToken" ],
    [ "NoConvergenceException", "exceptioncom_1_1sun_1_1star_1_1sheet_1_1NoConvergenceException.html", null ],
    [ "RangeSelectionArguments", "servicecom_1_1sun_1_1star_1_1sheet_1_1RangeSelectionArguments.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1RangeSelectionArguments" ],
    [ "RangeSelectionEvent", "structcom_1_1sun_1_1star_1_1sheet_1_1RangeSelectionEvent.html", "structcom_1_1sun_1_1star_1_1sheet_1_1RangeSelectionEvent" ],
    [ "RecentFunctions", "servicecom_1_1sun_1_1star_1_1sheet_1_1RecentFunctions.html", null ],
    [ "ResultEvent", "structcom_1_1sun_1_1star_1_1sheet_1_1ResultEvent.html", "structcom_1_1sun_1_1star_1_1sheet_1_1ResultEvent" ],
    [ "Scenario", "servicecom_1_1sun_1_1star_1_1sheet_1_1Scenario.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1Scenario" ],
    [ "Scenarios", "servicecom_1_1sun_1_1star_1_1sheet_1_1Scenarios.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1Scenarios" ],
    [ "ScenariosEnumeration", "servicecom_1_1sun_1_1star_1_1sheet_1_1ScenariosEnumeration.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1ScenariosEnumeration" ],
    [ "Shape", "servicecom_1_1sun_1_1star_1_1sheet_1_1Shape.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1Shape" ],
    [ "SheetCell", "servicecom_1_1sun_1_1star_1_1sheet_1_1SheetCell.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1SheetCell" ],
    [ "SheetCellCursor", "servicecom_1_1sun_1_1star_1_1sheet_1_1SheetCellCursor.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1SheetCellCursor" ],
    [ "SheetCellRange", "servicecom_1_1sun_1_1star_1_1sheet_1_1SheetCellRange.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1SheetCellRange" ],
    [ "SheetCellRanges", "servicecom_1_1sun_1_1star_1_1sheet_1_1SheetCellRanges.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1SheetCellRanges" ],
    [ "SheetCellRangesEnumeration", "servicecom_1_1sun_1_1star_1_1sheet_1_1SheetCellRangesEnumeration.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1SheetCellRangesEnumeration" ],
    [ "SheetFilterDescriptor", "servicecom_1_1sun_1_1star_1_1sheet_1_1SheetFilterDescriptor.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1SheetFilterDescriptor" ],
    [ "SheetLink", "servicecom_1_1sun_1_1star_1_1sheet_1_1SheetLink.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1SheetLink" ],
    [ "SheetLinks", "servicecom_1_1sun_1_1star_1_1sheet_1_1SheetLinks.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1SheetLinks" ],
    [ "SheetLinksEnumeration", "servicecom_1_1sun_1_1star_1_1sheet_1_1SheetLinksEnumeration.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1SheetLinksEnumeration" ],
    [ "SheetRangesQuery", "servicecom_1_1sun_1_1star_1_1sheet_1_1SheetRangesQuery.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1SheetRangesQuery" ],
    [ "SheetSortDescriptor", "servicecom_1_1sun_1_1star_1_1sheet_1_1SheetSortDescriptor.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1SheetSortDescriptor" ],
    [ "SheetSortDescriptor2", "servicecom_1_1sun_1_1star_1_1sheet_1_1SheetSortDescriptor2.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1SheetSortDescriptor2" ],
    [ "SingleReference", "structcom_1_1sun_1_1star_1_1sheet_1_1SingleReference.html", "structcom_1_1sun_1_1star_1_1sheet_1_1SingleReference" ],
    [ "Solver", "servicecom_1_1sun_1_1star_1_1sheet_1_1Solver.html", null ],
    [ "SolverConstraint", "structcom_1_1sun_1_1star_1_1sheet_1_1SolverConstraint.html", "structcom_1_1sun_1_1star_1_1sheet_1_1SolverConstraint" ],
    [ "Spreadsheet", "servicecom_1_1sun_1_1star_1_1sheet_1_1Spreadsheet.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1Spreadsheet" ],
    [ "SpreadsheetDocument", "servicecom_1_1sun_1_1star_1_1sheet_1_1SpreadsheetDocument.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1SpreadsheetDocument" ],
    [ "SpreadsheetDocumentSettings", "servicecom_1_1sun_1_1star_1_1sheet_1_1SpreadsheetDocumentSettings.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1SpreadsheetDocumentSettings" ],
    [ "SpreadsheetDrawPage", "servicecom_1_1sun_1_1star_1_1sheet_1_1SpreadsheetDrawPage.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1SpreadsheetDrawPage" ],
    [ "Spreadsheets", "servicecom_1_1sun_1_1star_1_1sheet_1_1Spreadsheets.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1Spreadsheets" ],
    [ "SpreadsheetsEnumeration", "servicecom_1_1sun_1_1star_1_1sheet_1_1SpreadsheetsEnumeration.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1SpreadsheetsEnumeration" ],
    [ "SpreadsheetView", "servicecom_1_1sun_1_1star_1_1sheet_1_1SpreadsheetView.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1SpreadsheetView" ],
    [ "SpreadsheetViewPane", "servicecom_1_1sun_1_1star_1_1sheet_1_1SpreadsheetViewPane.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1SpreadsheetViewPane" ],
    [ "SpreadsheetViewPanesEnumeration", "servicecom_1_1sun_1_1star_1_1sheet_1_1SpreadsheetViewPanesEnumeration.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1SpreadsheetViewPanesEnumeration" ],
    [ "SpreadsheetViewSettings", "servicecom_1_1sun_1_1star_1_1sheet_1_1SpreadsheetViewSettings.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1SpreadsheetViewSettings" ],
    [ "SubTotalColumn", "structcom_1_1sun_1_1star_1_1sheet_1_1SubTotalColumn.html", "structcom_1_1sun_1_1star_1_1sheet_1_1SubTotalColumn" ],
    [ "SubTotalDescriptor", "servicecom_1_1sun_1_1star_1_1sheet_1_1SubTotalDescriptor.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1SubTotalDescriptor" ],
    [ "SubTotalField", "servicecom_1_1sun_1_1star_1_1sheet_1_1SubTotalField.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1SubTotalField" ],
    [ "SubTotalFieldsEnumeration", "servicecom_1_1sun_1_1star_1_1sheet_1_1SubTotalFieldsEnumeration.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1SubTotalFieldsEnumeration" ],
    [ "TableAutoFormat", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormat.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormat" ],
    [ "TableAutoFormatEnumeration", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatEnumeration.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatEnumeration" ],
    [ "TableAutoFormatField", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField" ],
    [ "TableAutoFormats", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormats.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormats" ],
    [ "TableAutoFormatsEnumeration", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatsEnumeration.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatsEnumeration" ],
    [ "TableCellStyle", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableCellStyle.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableCellStyle" ],
    [ "TableConditionalEntry", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableConditionalEntry.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableConditionalEntry" ],
    [ "TableConditionalEntryEnumeration", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableConditionalEntryEnumeration.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableConditionalEntryEnumeration" ],
    [ "TableConditionalFormat", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableConditionalFormat.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableConditionalFormat" ],
    [ "TableFilterField", "structcom_1_1sun_1_1star_1_1sheet_1_1TableFilterField.html", "structcom_1_1sun_1_1star_1_1sheet_1_1TableFilterField" ],
    [ "TableFilterField2", "structcom_1_1sun_1_1star_1_1sheet_1_1TableFilterField2.html", "structcom_1_1sun_1_1star_1_1sheet_1_1TableFilterField2" ],
    [ "TableFilterField3", "structcom_1_1sun_1_1star_1_1sheet_1_1TableFilterField3.html", "structcom_1_1sun_1_1star_1_1sheet_1_1TableFilterField3" ],
    [ "TablePageBreakData", "structcom_1_1sun_1_1star_1_1sheet_1_1TablePageBreakData.html", "structcom_1_1sun_1_1star_1_1sheet_1_1TablePageBreakData" ],
    [ "TablePageStyle", "servicecom_1_1sun_1_1star_1_1sheet_1_1TablePageStyle.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1TablePageStyle" ],
    [ "TableValidation", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableValidation.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableValidation" ],
    [ "UniqueCellFormatRanges", "servicecom_1_1sun_1_1star_1_1sheet_1_1UniqueCellFormatRanges.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1UniqueCellFormatRanges" ],
    [ "UniqueCellFormatRangesEnumeration", "servicecom_1_1sun_1_1star_1_1sheet_1_1UniqueCellFormatRangesEnumeration.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1UniqueCellFormatRangesEnumeration" ],
    [ "VolatileResult", "servicecom_1_1sun_1_1star_1_1sheet_1_1VolatileResult.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1VolatileResult" ],
    [ "XActivationBroadcaster", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XActivationBroadcaster.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XActivationBroadcaster" ],
    [ "XActivationEventListener", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XActivationEventListener.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XActivationEventListener" ],
    [ "XAddIn", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XAddIn.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XAddIn" ],
    [ "XAreaLink", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XAreaLink.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XAreaLink" ],
    [ "XAreaLinks", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XAreaLinks.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XAreaLinks" ],
    [ "XArrayFormulaRange", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XArrayFormulaRange.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XArrayFormulaRange" ],
    [ "XArrayFormulaTokens", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XArrayFormulaTokens.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XArrayFormulaTokens" ],
    [ "XCalculatable", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XCalculatable.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XCalculatable" ],
    [ "XCellAddressable", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XCellAddressable.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XCellAddressable" ],
    [ "XCellFormatRangesSupplier", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XCellFormatRangesSupplier.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XCellFormatRangesSupplier" ],
    [ "XCellRangeAddressable", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XCellRangeAddressable.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XCellRangeAddressable" ],
    [ "XCellRangeData", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XCellRangeData.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XCellRangeData" ],
    [ "XCellRangeFormula", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XCellRangeFormula.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XCellRangeFormula" ],
    [ "XCellRangeMovement", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XCellRangeMovement.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XCellRangeMovement" ],
    [ "XCellRangeReferrer", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XCellRangeReferrer.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XCellRangeReferrer" ],
    [ "XCellRangesAccess", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XCellRangesAccess.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XCellRangesAccess" ],
    [ "XCellRangesQuery", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XCellRangesQuery.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XCellRangesQuery" ],
    [ "XCellSeries", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XCellSeries.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XCellSeries" ],
    [ "XColorScaleEntry", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XColorScaleEntry.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XColorScaleEntry" ],
    [ "XCompatibilityNames", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XCompatibilityNames.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XCompatibilityNames" ],
    [ "XConditionalFormat", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XConditionalFormat.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XConditionalFormat" ],
    [ "XConditionalFormats", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XConditionalFormats.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XConditionalFormats" ],
    [ "XConditionEntry", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XConditionEntry.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XConditionEntry" ],
    [ "XConsolidatable", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XConsolidatable.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XConsolidatable" ],
    [ "XConsolidationDescriptor", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XConsolidationDescriptor.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XConsolidationDescriptor" ],
    [ "XDataBarEntry", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XDataBarEntry.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XDataBarEntry" ],
    [ "XDatabaseRange", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XDatabaseRange.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XDatabaseRange" ],
    [ "XDatabaseRanges", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XDatabaseRanges.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XDatabaseRanges" ],
    [ "XDataPilotDataLayoutFieldSupplier", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XDataPilotDataLayoutFieldSupplier.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XDataPilotDataLayoutFieldSupplier" ],
    [ "XDataPilotDescriptor", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XDataPilotDescriptor.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XDataPilotDescriptor" ],
    [ "XDataPilotField", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XDataPilotField.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XDataPilotField" ],
    [ "XDataPilotFieldGrouping", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XDataPilotFieldGrouping.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XDataPilotFieldGrouping" ],
    [ "XDataPilotMemberResults", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XDataPilotMemberResults.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XDataPilotMemberResults" ],
    [ "XDataPilotResults", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XDataPilotResults.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XDataPilotResults" ],
    [ "XDataPilotTable", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XDataPilotTable.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XDataPilotTable" ],
    [ "XDataPilotTable2", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XDataPilotTable2.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XDataPilotTable2" ],
    [ "XDataPilotTables", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XDataPilotTables.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XDataPilotTables" ],
    [ "XDataPilotTablesSupplier", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XDataPilotTablesSupplier.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XDataPilotTablesSupplier" ],
    [ "XDDELink", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XDDELink.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XDDELink" ],
    [ "XDDELinkResults", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XDDELinkResults.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XDDELinkResults" ],
    [ "XDDELinks", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XDDELinks.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XDDELinks" ],
    [ "XDimensionsSupplier", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XDimensionsSupplier.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XDimensionsSupplier" ],
    [ "XDocumentAuditing", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XDocumentAuditing.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XDocumentAuditing" ],
    [ "XDrillDownDataSupplier", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XDrillDownDataSupplier.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XDrillDownDataSupplier" ],
    [ "XEnhancedMouseClickBroadcaster", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XEnhancedMouseClickBroadcaster.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XEnhancedMouseClickBroadcaster" ],
    [ "XExternalDocLink", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XExternalDocLink.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XExternalDocLink" ],
    [ "XExternalDocLinks", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XExternalDocLinks.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XExternalDocLinks" ],
    [ "XExternalSheetCache", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XExternalSheetCache.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XExternalSheetCache" ],
    [ "XExternalSheetName", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XExternalSheetName.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XExternalSheetName" ],
    [ "XFillAcrossSheet", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XFillAcrossSheet.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XFillAcrossSheet" ],
    [ "XFilterFormulaParser", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XFilterFormulaParser.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XFilterFormulaParser" ],
    [ "XFormulaOpCodeMapper", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XFormulaOpCodeMapper.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XFormulaOpCodeMapper" ],
    [ "XFormulaParser", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XFormulaParser.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XFormulaParser" ],
    [ "XFormulaQuery", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XFormulaQuery.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XFormulaQuery" ],
    [ "XFormulaTokens", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XFormulaTokens.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XFormulaTokens" ],
    [ "XFunctionAccess", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XFunctionAccess.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XFunctionAccess" ],
    [ "XFunctionDescriptions", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XFunctionDescriptions.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XFunctionDescriptions" ],
    [ "XGlobalSheetSettings", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XGlobalSheetSettings.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XGlobalSheetSettings" ],
    [ "XGoalSeek", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XGoalSeek.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XGoalSeek" ],
    [ "XHeaderFooterContent", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XHeaderFooterContent.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XHeaderFooterContent" ],
    [ "XHierarchiesSupplier", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XHierarchiesSupplier.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XHierarchiesSupplier" ],
    [ "XIconSetEntry", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XIconSetEntry.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XIconSetEntry" ],
    [ "XLabelRange", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XLabelRange.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XLabelRange" ],
    [ "XLabelRanges", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XLabelRanges.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XLabelRanges" ],
    [ "XLevelsSupplier", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XLevelsSupplier.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XLevelsSupplier" ],
    [ "XMembersAccess", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XMembersAccess.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XMembersAccess" ],
    [ "XMembersSupplier", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XMembersSupplier.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XMembersSupplier" ],
    [ "XMultiFormulaTokens", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XMultiFormulaTokens.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XMultiFormulaTokens" ],
    [ "XMultipleOperation", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XMultipleOperation.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XMultipleOperation" ],
    [ "XNamedRange", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XNamedRange.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XNamedRange" ],
    [ "XNamedRanges", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XNamedRanges.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XNamedRanges" ],
    [ "XPrintAreas", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XPrintAreas.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XPrintAreas" ],
    [ "XRangeSelection", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XRangeSelection.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XRangeSelection" ],
    [ "XRangeSelectionChangeListener", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XRangeSelectionChangeListener.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XRangeSelectionChangeListener" ],
    [ "XRangeSelectionListener", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XRangeSelectionListener.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XRangeSelectionListener" ],
    [ "XRecentFunctions", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XRecentFunctions.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XRecentFunctions" ],
    [ "XResultListener", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XResultListener.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XResultListener" ],
    [ "XScenario", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XScenario.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XScenario" ],
    [ "XScenarioEnhanced", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XScenarioEnhanced.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XScenarioEnhanced" ],
    [ "XScenarios", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XScenarios.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XScenarios" ],
    [ "XScenariosSupplier", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XScenariosSupplier.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XScenariosSupplier" ],
    [ "XSelectedSheetsSupplier", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSelectedSheetsSupplier.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSelectedSheetsSupplier" ],
    [ "XSheetAnnotation", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetAnnotation.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetAnnotation" ],
    [ "XSheetAnnotationAnchor", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetAnnotationAnchor.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetAnnotationAnchor" ],
    [ "XSheetAnnotations", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetAnnotations.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetAnnotations" ],
    [ "XSheetAnnotationShapeSupplier", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetAnnotationShapeSupplier.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetAnnotationShapeSupplier" ],
    [ "XSheetAnnotationsSupplier", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetAnnotationsSupplier.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetAnnotationsSupplier" ],
    [ "XSheetAuditing", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetAuditing.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetAuditing" ],
    [ "XSheetCellCursor", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetCellCursor.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetCellCursor" ],
    [ "XSheetCellRange", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetCellRange.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetCellRange" ],
    [ "XSheetCellRangeContainer", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetCellRangeContainer.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetCellRangeContainer" ],
    [ "XSheetCellRanges", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetCellRanges.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetCellRanges" ],
    [ "XSheetCondition", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetCondition.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetCondition" ],
    [ "XSheetCondition2", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetCondition2.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetCondition2" ],
    [ "XSheetConditionalEntries", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetConditionalEntries.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetConditionalEntries" ],
    [ "XSheetConditionalEntry", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetConditionalEntry.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetConditionalEntry" ],
    [ "XSheetFilterable", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetFilterable.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetFilterable" ],
    [ "XSheetFilterableEx", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetFilterableEx.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetFilterableEx" ],
    [ "XSheetFilterDescriptor", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetFilterDescriptor.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetFilterDescriptor" ],
    [ "XSheetFilterDescriptor2", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetFilterDescriptor2.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetFilterDescriptor2" ],
    [ "XSheetFilterDescriptor3", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetFilterDescriptor3.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetFilterDescriptor3" ],
    [ "XSheetLinkable", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetLinkable.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetLinkable" ],
    [ "XSheetOperation", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetOperation.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetOperation" ],
    [ "XSheetOutline", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetOutline.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetOutline" ],
    [ "XSheetPageBreak", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetPageBreak.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetPageBreak" ],
    [ "XSheetPastable", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetPastable.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetPastable" ],
    [ "XSheetRange", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetRange.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetRange" ],
    [ "XSolver", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSolver.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSolver" ],
    [ "XSolverDescription", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSolverDescription.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSolverDescription" ],
    [ "XSpreadsheet", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSpreadsheet.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSpreadsheet" ],
    [ "XSpreadsheetDocument", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSpreadsheetDocument.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSpreadsheetDocument" ],
    [ "XSpreadsheets", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSpreadsheets.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSpreadsheets" ],
    [ "XSpreadsheets2", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSpreadsheets2.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSpreadsheets2" ],
    [ "XSpreadsheetView", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSpreadsheetView.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSpreadsheetView" ],
    [ "XSubTotalCalculatable", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSubTotalCalculatable.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSubTotalCalculatable" ],
    [ "XSubTotalDescriptor", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSubTotalDescriptor.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSubTotalDescriptor" ],
    [ "XSubTotalField", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSubTotalField.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSubTotalField" ],
    [ "XUniqueCellFormatRangesSupplier", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XUniqueCellFormatRangesSupplier.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XUniqueCellFormatRangesSupplier" ],
    [ "XUnnamedDatabaseRanges", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XUnnamedDatabaseRanges.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XUnnamedDatabaseRanges" ],
    [ "XUsedAreaCursor", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XUsedAreaCursor.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XUsedAreaCursor" ],
    [ "XViewFreezable", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XViewFreezable.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XViewFreezable" ],
    [ "XViewPane", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XViewPane.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XViewPane" ],
    [ "XViewPanesSupplier", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XViewPanesSupplier.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XViewPanesSupplier" ],
    [ "XViewSplitable", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XViewSplitable.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XViewSplitable" ],
    [ "XVolatileResult", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XVolatileResult.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XVolatileResult" ],
    [ "Border", "namespacecom_1_1sun_1_1star_1_1sheet.html#aea307cd05a4c363d9cac3828a62f4127", [
      [ "TOP", "namespacecom_1_1sun_1_1star_1_1sheet.html#aea307cd05a4c363d9cac3828a62f4127a0ad44897a70fba309c24a5b6007de3e3", null ],
      [ "BOTTOM", "namespacecom_1_1sun_1_1star_1_1sheet.html#aea307cd05a4c363d9cac3828a62f4127a8c371f4e766fb2c49c219bbc88989461", null ],
      [ "RIGHT", "namespacecom_1_1sun_1_1star_1_1sheet.html#a93cdb08109d5d34543f2fe04d1ef605aa2d192e0d040aa72b0c0e855aaf9462e5", null ],
      [ "LEFT", "namespacecom_1_1sun_1_1star_1_1sheet.html#af2bbbff47b7abe36f258e59b1351e422a2349c85ca7362adcde4c67fbd81a4432", null ]
    ] ],
    [ "CellDeleteMode", "namespacecom_1_1sun_1_1star_1_1sheet.html#af2bbbff47b7abe36f258e59b1351e422", [
      [ "NONE", "namespacecom_1_1sun_1_1star_1_1sheet.html#a34cdda19a5183f39256021e0c2bc46cca899caa602e4fff675b17cdbab33607ec", null ],
      [ "UP", "namespacecom_1_1sun_1_1star_1_1sheet.html#af2bbbff47b7abe36f258e59b1351e422aba595d8bca8bc5e67c37c0a9d89becfa", null ],
      [ "LEFT", "namespacecom_1_1sun_1_1star_1_1sheet.html#af2bbbff47b7abe36f258e59b1351e422a2349c85ca7362adcde4c67fbd81a4432", null ],
      [ "ROWS", "namespacecom_1_1sun_1_1star_1_1sheet.html#a93cdb08109d5d34543f2fe04d1ef605aab316a8365df38296348921f109879648", null ],
      [ "COLUMNS", "namespacecom_1_1sun_1_1star_1_1sheet.html#a93cdb08109d5d34543f2fe04d1ef605aabd5634f52bc75fd2f125f15e9957de68", null ]
    ] ],
    [ "CellInsertMode", "namespacecom_1_1sun_1_1star_1_1sheet.html#a93cdb08109d5d34543f2fe04d1ef605a", [
      [ "NONE", "namespacecom_1_1sun_1_1star_1_1sheet.html#a34cdda19a5183f39256021e0c2bc46cca899caa602e4fff675b17cdbab33607ec", null ],
      [ "DOWN", "namespacecom_1_1sun_1_1star_1_1sheet.html#a93cdb08109d5d34543f2fe04d1ef605aa9b0b4a95b99523966e0e34ffdadac9da", null ],
      [ "RIGHT", "namespacecom_1_1sun_1_1star_1_1sheet.html#a93cdb08109d5d34543f2fe04d1ef605aa2d192e0d040aa72b0c0e855aaf9462e5", null ],
      [ "ROWS", "namespacecom_1_1sun_1_1star_1_1sheet.html#a93cdb08109d5d34543f2fe04d1ef605aab316a8365df38296348921f109879648", null ],
      [ "COLUMNS", "namespacecom_1_1sun_1_1star_1_1sheet.html#a93cdb08109d5d34543f2fe04d1ef605aabd5634f52bc75fd2f125f15e9957de68", null ]
    ] ],
    [ "ConditionOperator", "namespacecom_1_1sun_1_1star_1_1sheet.html#adab1b2b49825a75bed998dd77963eff9", [
      [ "NONE", "namespacecom_1_1sun_1_1star_1_1sheet.html#a34cdda19a5183f39256021e0c2bc46cca899caa602e4fff675b17cdbab33607ec", null ],
      [ "EQUAL", "namespacecom_1_1sun_1_1star_1_1sheet.html#a491ab8ed5b7b5809e7be869d26b071cfab61255a4a9a516506f9d9a68f164873d", null ],
      [ "NOT_EQUAL", "namespacecom_1_1sun_1_1star_1_1sheet.html#af9e5fd8fd26fc252748d97ebd68ea6b1a65d2cc14312fc4b7ced6811af807551e", null ],
      [ "GREATER", "namespacecom_1_1sun_1_1star_1_1sheet.html#af9e5fd8fd26fc252748d97ebd68ea6b1aeb2bcac2e813e1f8d0f4da02e5f1bd56", null ],
      [ "GREATER_EQUAL", "namespacecom_1_1sun_1_1star_1_1sheet.html#a491ab8ed5b7b5809e7be869d26b071cfa9be07a0b922eebb04f2dabc32c83419d", null ],
      [ "LESS", "namespacecom_1_1sun_1_1star_1_1sheet.html#af9e5fd8fd26fc252748d97ebd68ea6b1ace23c094d382970cae684969ba8d4880", null ],
      [ "LESS_EQUAL", "namespacecom_1_1sun_1_1star_1_1sheet.html#a491ab8ed5b7b5809e7be869d26b071cfa615fbea5aa163ceb3fdb47472af722c2", null ],
      [ "BETWEEN", "namespacecom_1_1sun_1_1star_1_1sheet.html#adab1b2b49825a75bed998dd77963eff9a8a86033ada1240a0576a1ce24d8d307b", null ],
      [ "NOT_BETWEEN", "namespacecom_1_1sun_1_1star_1_1sheet.html#adab1b2b49825a75bed998dd77963eff9a28cf996d6cd2be3be4120b465c61e7fd", null ],
      [ "FORMULA", "namespacecom_1_1sun_1_1star_1_1sheet.html#adab1b2b49825a75bed998dd77963eff9adbb4705ae7575b34b0956a848d130b9d", null ]
    ] ],
    [ "DataImportMode", "namespacecom_1_1sun_1_1star_1_1sheet.html#acf0761f72074fd2e59d1bb3ef690a2e6", [
      [ "NONE", "namespacecom_1_1sun_1_1star_1_1sheet.html#a34cdda19a5183f39256021e0c2bc46cca899caa602e4fff675b17cdbab33607ec", null ],
      [ "SQL", "namespacecom_1_1sun_1_1star_1_1sheet.html#acf0761f72074fd2e59d1bb3ef690a2e6a875bbdb13a7aece448f22c2d31f50d58", null ],
      [ "TABLE", "namespacecom_1_1sun_1_1star_1_1sheet.html#acf0761f72074fd2e59d1bb3ef690a2e6a2e160f29fc076de5496a2b9968be9cc1", null ],
      [ "QUERY", "namespacecom_1_1sun_1_1star_1_1sheet.html#acf0761f72074fd2e59d1bb3ef690a2e6a21043ddfa5289b4cf14cd4e3f5a89b62", null ]
    ] ],
    [ "DataPilotFieldOrientation", "namespacecom_1_1sun_1_1star_1_1sheet.html#a686c797e7cb837947558aa11c946245a", [
      [ "HIDDEN", "namespacecom_1_1sun_1_1star_1_1sheet.html#a686c797e7cb837947558aa11c946245aa41ae0a505430bf564b119bc82db7592d", null ],
      [ "COLUMN", "namespacecom_1_1sun_1_1star_1_1sheet.html#a91d4f5595c9dc2a8c09e532e59f395d9a727e9b9696032b380d0072840595ef05", null ],
      [ "ROW", "namespacecom_1_1sun_1_1star_1_1sheet.html#a91d4f5595c9dc2a8c09e532e59f395d9afa778e2e885ea874d6cb6082d75b627f", null ],
      [ "PAGE", "namespacecom_1_1sun_1_1star_1_1sheet.html#a686c797e7cb837947558aa11c946245aab788d9e2cde88d51a5cda409f75db490", null ],
      [ "DATA", "namespacecom_1_1sun_1_1star_1_1sheet.html#a686c797e7cb837947558aa11c946245aa9d7d6f31868d66330397c967c4afd2d2", null ]
    ] ],
    [ "DDELinkMode", "namespacecom_1_1sun_1_1star_1_1sheet.html#a1b95ca535d92ad726d77981ea3d8ef8b", [
      [ "DEFAULT", "namespacecom_1_1sun_1_1star_1_1sheet.html#a1b95ca535d92ad726d77981ea3d8ef8ba88ec7d5086d2469ba843c7fcceade8a6", null ],
      [ "ENGLISH", "namespacecom_1_1sun_1_1star_1_1sheet.html#a1b95ca535d92ad726d77981ea3d8ef8bafb297577dad4cc723ce8e94430f3defc", null ],
      [ "TEXT", "namespacecom_1_1sun_1_1star_1_1sheet.html#a1b95ca535d92ad726d77981ea3d8ef8ba9a4a47c1606e295076055a9cc4373197", null ]
    ] ],
    [ "FillDateMode", "namespacecom_1_1sun_1_1star_1_1sheet.html#a2ea1aac24b8de3ac28ac5a6ec79a80ca", [
      [ "FILL_DATE_DAY", "namespacecom_1_1sun_1_1star_1_1sheet.html#a2ea1aac24b8de3ac28ac5a6ec79a80caa3834c89ec9c3da181f359365a3516e38", null ],
      [ "FILL_DATE_WEEKDAY", "namespacecom_1_1sun_1_1star_1_1sheet.html#a2ea1aac24b8de3ac28ac5a6ec79a80caa39dea48a0e939ad207e827bac1ca181e", null ],
      [ "FILL_DATE_MONTH", "namespacecom_1_1sun_1_1star_1_1sheet.html#a2ea1aac24b8de3ac28ac5a6ec79a80caa72355f21c2b1aadc24d4af835f43f8e9", null ],
      [ "FILL_DATE_YEAR", "namespacecom_1_1sun_1_1star_1_1sheet.html#a2ea1aac24b8de3ac28ac5a6ec79a80caae3980862f731425fccd8ab73c1e18505", null ]
    ] ],
    [ "FillDirection", "namespacecom_1_1sun_1_1star_1_1sheet.html#aa8eeb1312106b2d89cd26342fa09aac9", [
      [ "TO_BOTTOM", "namespacecom_1_1sun_1_1star_1_1sheet.html#aa8eeb1312106b2d89cd26342fa09aac9a4f1d873c6c52cc0e01157c9b23079cb4", null ],
      [ "TO_RIGHT", "namespacecom_1_1sun_1_1star_1_1sheet.html#aa8eeb1312106b2d89cd26342fa09aac9ab8604a32917c39fadc83a00badd68442", null ],
      [ "TO_TOP", "namespacecom_1_1sun_1_1star_1_1sheet.html#aa8eeb1312106b2d89cd26342fa09aac9aad8e840a5af314d2100f9f476602f677", null ],
      [ "TO_LEFT", "namespacecom_1_1sun_1_1star_1_1sheet.html#aa8eeb1312106b2d89cd26342fa09aac9a8a69bda9475427c58bf9624eae1e894a", null ]
    ] ],
    [ "FillMode", "namespacecom_1_1sun_1_1star_1_1sheet.html#a75a9acd74effffae38daed55136b0980", [
      [ "SIMPLE", "namespacecom_1_1sun_1_1star_1_1sheet.html#a75a9acd74effffae38daed55136b0980a1a6b6e9893ec9e5d9710335b4c74d3f6", null ],
      [ "LINEAR", "namespacecom_1_1sun_1_1star_1_1sheet.html#a75a9acd74effffae38daed55136b0980adc101ebf31c49c2d4b80b7c6f59f22cb", null ],
      [ "GROWTH", "namespacecom_1_1sun_1_1star_1_1sheet.html#a75a9acd74effffae38daed55136b0980a14f878b5967a8b1031e1d808400bb828", null ],
      [ "DATE", "namespacecom_1_1sun_1_1star_1_1sheet.html#aa5aa6dbecaeb5e18a476b0a58279c57aac7cae48a020e5f4fb68bd638aa5fb7d9", null ],
      [ "AUTO", "namespacecom_1_1sun_1_1star_1_1sheet.html#ad184d5bd9055f3b4fd57ce72c781758da135407ee7af1402d3e49739d9c4ad06b", null ]
    ] ],
    [ "FilterConnection", "namespacecom_1_1sun_1_1star_1_1sheet.html#a946b76fb59cd525a1296ff815333d110", [
      [ "AND", "namespacecom_1_1sun_1_1star_1_1sheet.html#a946b76fb59cd525a1296ff815333d110a865555c9f2e0458a7078486aa1b3254f", null ],
      [ "OR", "namespacecom_1_1sun_1_1star_1_1sheet.html#a946b76fb59cd525a1296ff815333d110a96727447c0ad447987df1c6415aef074", null ]
    ] ],
    [ "FilterOperator", "namespacecom_1_1sun_1_1star_1_1sheet.html#af9e5fd8fd26fc252748d97ebd68ea6b1", [
      [ "EMPTY", "namespacecom_1_1sun_1_1star_1_1sheet.html#af9e5fd8fd26fc252748d97ebd68ea6b1a2f0d18fc0d0fa4a6cd92dc328501874d", null ],
      [ "NOT_EMPTY", "namespacecom_1_1sun_1_1star_1_1sheet.html#af9e5fd8fd26fc252748d97ebd68ea6b1aff3982d21bd983d87b10549c9b938d6b", null ],
      [ "EQUAL", "namespacecom_1_1sun_1_1star_1_1sheet.html#a491ab8ed5b7b5809e7be869d26b071cfab61255a4a9a516506f9d9a68f164873d", null ],
      [ "NOT_EQUAL", "namespacecom_1_1sun_1_1star_1_1sheet.html#af9e5fd8fd26fc252748d97ebd68ea6b1a65d2cc14312fc4b7ced6811af807551e", null ],
      [ "GREATER", "namespacecom_1_1sun_1_1star_1_1sheet.html#af9e5fd8fd26fc252748d97ebd68ea6b1aeb2bcac2e813e1f8d0f4da02e5f1bd56", null ],
      [ "GREATER_EQUAL", "namespacecom_1_1sun_1_1star_1_1sheet.html#a491ab8ed5b7b5809e7be869d26b071cfa9be07a0b922eebb04f2dabc32c83419d", null ],
      [ "LESS", "namespacecom_1_1sun_1_1star_1_1sheet.html#af9e5fd8fd26fc252748d97ebd68ea6b1ace23c094d382970cae684969ba8d4880", null ],
      [ "LESS_EQUAL", "namespacecom_1_1sun_1_1star_1_1sheet.html#a491ab8ed5b7b5809e7be869d26b071cfa615fbea5aa163ceb3fdb47472af722c2", null ],
      [ "TOP_VALUES", "namespacecom_1_1sun_1_1star_1_1sheet.html#af9e5fd8fd26fc252748d97ebd68ea6b1ad7bebe138f907332fe3a37840baeb13b", null ],
      [ "TOP_PERCENT", "namespacecom_1_1sun_1_1star_1_1sheet.html#af9e5fd8fd26fc252748d97ebd68ea6b1ab9e9a1d576a572a4d3e68160295f3d0a", null ],
      [ "BOTTOM_VALUES", "namespacecom_1_1sun_1_1star_1_1sheet.html#af9e5fd8fd26fc252748d97ebd68ea6b1a92e72a303b310ad6cdceab6620c3b269", null ],
      [ "BOTTOM_PERCENT", "namespacecom_1_1sun_1_1star_1_1sheet.html#af9e5fd8fd26fc252748d97ebd68ea6b1ad9a514ec7dda78630beaac16ac69343d", null ]
    ] ],
    [ "GeneralFunction", "namespacecom_1_1sun_1_1star_1_1sheet.html#ad184d5bd9055f3b4fd57ce72c781758d", [
      [ "NONE", "namespacecom_1_1sun_1_1star_1_1sheet.html#a34cdda19a5183f39256021e0c2bc46cca899caa602e4fff675b17cdbab33607ec", null ],
      [ "AUTO", "namespacecom_1_1sun_1_1star_1_1sheet.html#ad184d5bd9055f3b4fd57ce72c781758da135407ee7af1402d3e49739d9c4ad06b", null ],
      [ "SUM", "namespacecom_1_1sun_1_1star_1_1sheet.html#ad184d5bd9055f3b4fd57ce72c781758da82c030bf31e2d975e6a85cf67ba88bb4", null ],
      [ "COUNT", "namespacecom_1_1sun_1_1star_1_1sheet.html#ad184d5bd9055f3b4fd57ce72c781758da2addb49878f50c95dc669e5fdbd130a2", null ],
      [ "AVERAGE", "namespacecom_1_1sun_1_1star_1_1sheet.html#ad184d5bd9055f3b4fd57ce72c781758dab6f2220659ddcb84a0622d4aa4e0b112", null ],
      [ "MAX", "namespacecom_1_1sun_1_1star_1_1sheet.html#ad184d5bd9055f3b4fd57ce72c781758dad7e097bda6d981de2520f49fe74c25b7", null ],
      [ "MIN", "namespacecom_1_1sun_1_1star_1_1sheet.html#ad184d5bd9055f3b4fd57ce72c781758da957e8250f68e7b5677b22397c2c1b51e", null ],
      [ "PRODUCT", "namespacecom_1_1sun_1_1star_1_1sheet.html#ad184d5bd9055f3b4fd57ce72c781758dacb6911398e0068f545a31b82bcdef3e4", null ],
      [ "COUNTNUMS", "namespacecom_1_1sun_1_1star_1_1sheet.html#ad184d5bd9055f3b4fd57ce72c781758dac899b94c1fa11933dc5e5bc977a2bf8c", null ],
      [ "STDEV", "namespacecom_1_1sun_1_1star_1_1sheet.html#ad184d5bd9055f3b4fd57ce72c781758da543457e2b7362e7d4112e4465b9ddc68", null ],
      [ "STDEVP", "namespacecom_1_1sun_1_1star_1_1sheet.html#ad184d5bd9055f3b4fd57ce72c781758dafc15e2d774db456f7479fb082b526a14", null ],
      [ "VAR", "namespacecom_1_1sun_1_1star_1_1sheet.html#ad184d5bd9055f3b4fd57ce72c781758daf68346ce0bfce7ab2ca0a240f5132863", null ],
      [ "VARP", "namespacecom_1_1sun_1_1star_1_1sheet.html#ad184d5bd9055f3b4fd57ce72c781758dac774be73d9967fbec5e923eef08f9910", null ]
    ] ],
    [ "PasteOperation", "namespacecom_1_1sun_1_1star_1_1sheet.html#af53d63b24461405946937e0b962a8a9b", [
      [ "NONE", "namespacecom_1_1sun_1_1star_1_1sheet.html#a34cdda19a5183f39256021e0c2bc46cca899caa602e4fff675b17cdbab33607ec", null ],
      [ "ADD", "namespacecom_1_1sun_1_1star_1_1sheet.html#af53d63b24461405946937e0b962a8a9bacfcf145f2788bf340ff3f3098bc54909", null ],
      [ "SUBTRACT", "namespacecom_1_1sun_1_1star_1_1sheet.html#af53d63b24461405946937e0b962a8a9baad8ff967f143b54da6d2112fb5858e8c", null ],
      [ "MULTIPLY", "namespacecom_1_1sun_1_1star_1_1sheet.html#af53d63b24461405946937e0b962a8a9bae59a728a365f9d6b2643057973cdf4c3", null ],
      [ "DIVIDE", "namespacecom_1_1sun_1_1star_1_1sheet.html#af53d63b24461405946937e0b962a8a9ba0cb86713ee09fe297dde9ab03d50d5da", null ]
    ] ],
    [ "SheetLinkMode", "namespacecom_1_1sun_1_1star_1_1sheet.html#a34cdda19a5183f39256021e0c2bc46cc", [
      [ "NONE", "namespacecom_1_1sun_1_1star_1_1sheet.html#a34cdda19a5183f39256021e0c2bc46cca899caa602e4fff675b17cdbab33607ec", null ],
      [ "NORMAL", "namespacecom_1_1sun_1_1star_1_1sheet.html#a34cdda19a5183f39256021e0c2bc46cca50d1448013c6f17125caee18aa418af7", null ],
      [ "VALUE", "namespacecom_1_1sun_1_1star_1_1sheet.html#a34cdda19a5183f39256021e0c2bc46ccad3a10aa8b647d6a6db651ef882ff8bff", null ]
    ] ],
    [ "SolverConstraintOperator", "namespacecom_1_1sun_1_1star_1_1sheet.html#a491ab8ed5b7b5809e7be869d26b071cf", [
      [ "LESS_EQUAL", "namespacecom_1_1sun_1_1star_1_1sheet.html#a491ab8ed5b7b5809e7be869d26b071cfa615fbea5aa163ceb3fdb47472af722c2", null ],
      [ "EQUAL", "namespacecom_1_1sun_1_1star_1_1sheet.html#a491ab8ed5b7b5809e7be869d26b071cfab61255a4a9a516506f9d9a68f164873d", null ],
      [ "GREATER_EQUAL", "namespacecom_1_1sun_1_1star_1_1sheet.html#a491ab8ed5b7b5809e7be869d26b071cfa9be07a0b922eebb04f2dabc32c83419d", null ],
      [ "INTEGER", "namespacecom_1_1sun_1_1star_1_1sheet.html#a491ab8ed5b7b5809e7be869d26b071cfa5a063e265d2ac903b6808e9f6e73ec46", null ],
      [ "BINARY", "namespacecom_1_1sun_1_1star_1_1sheet.html#a491ab8ed5b7b5809e7be869d26b071cfaecafbc1299672a8c1521cc0d5f1ae986", null ]
    ] ],
    [ "TableOperationMode", "namespacecom_1_1sun_1_1star_1_1sheet.html#a91d4f5595c9dc2a8c09e532e59f395d9", [
      [ "COLUMN", "namespacecom_1_1sun_1_1star_1_1sheet.html#a91d4f5595c9dc2a8c09e532e59f395d9a727e9b9696032b380d0072840595ef05", null ],
      [ "ROW", "namespacecom_1_1sun_1_1star_1_1sheet.html#a91d4f5595c9dc2a8c09e532e59f395d9afa778e2e885ea874d6cb6082d75b627f", null ],
      [ "BOTH", "namespacecom_1_1sun_1_1star_1_1sheet.html#a91d4f5595c9dc2a8c09e532e59f395d9a627abe5a430420baf29ebe1940a7f2fb", null ]
    ] ],
    [ "ValidationAlertStyle", "namespacecom_1_1sun_1_1star_1_1sheet.html#aecf58149730f4c8c5c18c70f3c7c5db7", [
      [ "STOP", "namespacecom_1_1sun_1_1star_1_1sheet.html#aecf58149730f4c8c5c18c70f3c7c5db7a679ee5320d66c8322e310daeb2ee99b8", null ],
      [ "WARNING", "namespacecom_1_1sun_1_1star_1_1sheet.html#aecf58149730f4c8c5c18c70f3c7c5db7a984de77c680eaff141ec910e25568a81", null ],
      [ "INFO", "namespacecom_1_1sun_1_1star_1_1sheet.html#aecf58149730f4c8c5c18c70f3c7c5db7a748005382152808a72b1a9177d9dc806", null ],
      [ "MACRO", "namespacecom_1_1sun_1_1star_1_1sheet.html#aecf58149730f4c8c5c18c70f3c7c5db7a3d1738a931468da77c233f1126436b81", null ]
    ] ],
    [ "ValidationType", "namespacecom_1_1sun_1_1star_1_1sheet.html#aa5aa6dbecaeb5e18a476b0a58279c57a", [
      [ "ANY", "namespacecom_1_1sun_1_1star_1_1sheet.html#aa5aa6dbecaeb5e18a476b0a58279c57aaa00374190265e7b6447db44977a7dff1", null ],
      [ "WHOLE", "namespacecom_1_1sun_1_1star_1_1sheet.html#aa5aa6dbecaeb5e18a476b0a58279c57aa22e41d649f93ab26b3fef686f088703e", null ],
      [ "DECIMAL", "namespacecom_1_1sun_1_1star_1_1sheet.html#aa5aa6dbecaeb5e18a476b0a58279c57aaf08a543d5a1549321682e12569d0fbd6", null ],
      [ "DATE", "namespacecom_1_1sun_1_1star_1_1sheet.html#aa5aa6dbecaeb5e18a476b0a58279c57aac7cae48a020e5f4fb68bd638aa5fb7d9", null ],
      [ "TIME", "namespacecom_1_1sun_1_1star_1_1sheet.html#aa5aa6dbecaeb5e18a476b0a58279c57aae9e4c627760f36823cdd153c24229157", null ],
      [ "TEXT_LEN", "namespacecom_1_1sun_1_1star_1_1sheet.html#aa5aa6dbecaeb5e18a476b0a58279c57aa455c2406a57715ed0f89b2210b556586", null ],
      [ "LIST", "namespacecom_1_1sun_1_1star_1_1sheet.html#aa5aa6dbecaeb5e18a476b0a58279c57aa25688e799536738ea469158ef15fd1c0", null ],
      [ "CUSTOM", "namespacecom_1_1sun_1_1star_1_1sheet.html#aa5aa6dbecaeb5e18a476b0a58279c57aa945d6010d321d9fe75cbba7b6f37f3b5", null ]
    ] ]
];